Logo AND Algorithmique Numérique Distribuée

Public GIT Repository
A few spelling mistakes and many replacements: [Ss]imgrid -> SimGrid.
authorArnaud Giersch <arnaud.giersch@univ-fcomte.fr>
Tue, 13 Jun 2023 19:51:48 +0000 (21:51 +0200)
committerArnaud Giersch <arnaud.giersch@univ-fcomte.fr>
Tue, 13 Jun 2023 20:41:14 +0000 (22:41 +0200)
[ci-skip]

48 files changed:
.github/workflows/git.yml
AUTHORS
CMakeLists.txt
ChangeLog
doc/doxygen/outcomes_vizu.doc
docs/source/Tutorial_DAG.rst
docs/source/app_s4u.rst
docs/source/app_smpi.rst
docs/source/tuto_disk/Dockerfile
docs/source/tuto_network_calibration/Dockerfile
docs/source/tuto_network_calibration/dahu_platform_ckmeans.cpp
docs/source/tuto_network_calibration/dahu_platform_dhist.cpp
docs/source/tuto_network_calibration/network_calibration_tutorial.ipynb
docs/source/tuto_network_calibration/network_calibration_tutorial.rst
docs/source/tuto_s4u/draw_gantt.R
examples/README.rst
examples/cpp/maestro-set/s4u-maestro-set.cpp
examples/smpi/comm_dynamic_costs/comm-dynamic-cost.cpp
examples/smpi/simple-execute/simple-execute.c
include/simgrid/engine.h
include/simgrid/forward.h
include/simgrid/plugins/ns3.hpp
include/simgrid/s4u/Engine.hpp
include/xbt/base.h
include/xbt/misc.h
include/xbt/sysdep.h
setup.py
src/kernel/resource/models/network_ns3.cpp
src/mc/api/ClockVector.hpp
src/mc/api/State.hpp
src/mc/mc_record.hpp
src/s4u/s4u_Engine.cpp
src/simgrid/sg_config.cpp
src/smpi/colls/smpi_default_selector.cpp
src/smpi/include/smpi_replay.hpp
src/smpi/include/smpi_request.hpp
src/sthread/sthread.c
src/xbt/mallocator.c
teshsuite/s4u/monkey-masterworkers/monkey-masterworkers.cpp
teshsuite/s4u/monkey-masterworkers/monkey-masterworkers.py
teshsuite/smpi/MBI/CMakeLists.txt
teshsuite/smpi/coll-allreduce/coll-allreduce-papi.tesh
tools/cmake/DefinePackages.cmake
tools/jenkins/ci-starpu.sh
tools/jenkins/gfortran-simgrid.rc
tools/simgrid-monkey
tools/simgrid_convert_TI_traces.py
tools/simgrid_update_xml.pl

index 6a907d5..39d03c2 100644 (file)
@@ -51,7 +51,7 @@ jobs:
       - name: Create the success Message
         if: ${{ success() }}
         run: |
-          ver=$(grep set.SIMGRID_VERSION_MINOR CMakeLists.txt|sed 's/[^"]*"//'|sed 's/".*$//') echo "{\"attachments\": [{\"color\": \"#00FF00\", \"text\":\"Simgrid built successfully on ${{ matrix.config.name }}! ${{ github.server_url }}/${{ github.repository }}/actions/runs/${{ github.run_id }} \"}]}" > mattermost.json
+          ver=$(grep set.SIMGRID_VERSION_MINOR CMakeLists.txt|sed 's/[^"]*"//'|sed 's/".*$//') echo "{\"attachments\": [{\"color\": \"#00FF00\", \"text\":\"SimGrid built successfully on ${{ matrix.config.name }}! ${{ github.server_url }}/${{ github.repository }}/actions/runs/${{ github.run_id }} \"}]}" > mattermost.json
       - uses: komarnitskyi/action-mattermost-notification@v0.1.2-beta
         if: ${{ always() }}
         env:
diff --git a/AUTHORS b/AUTHORS
index 5e867f9..c8ce721 100644 (file)
--- a/AUTHORS
+++ b/AUTHORS
@@ -1,4 +1,4 @@
-Simgrid Core Team
+SimGrid Core Team
 _________________
 
 SimGrid is a joint project. Its main authors are (alphabetic order):
index 4157980..4a34d20 100644 (file)
@@ -955,7 +955,7 @@ message("        Documentation ...............: ${enable_documentation}")
 message("        Graphviz mode ...............: ${HAVE_GRAPHVIZ}")
 message("        Mallocators .................: ${enable_mallocators}")
 message("")
-message("        Simgrid dependencies ........: ${SIMGRID_DEP}")
+message("        SimGrid dependencies ........: ${SIMGRID_DEP}")
 message("")
 
 execute_process(COMMAND ${CMAKE_COMMAND} -E make_directory ${PROJECT_BINARY_DIR}/Testing/Notes/)
index 8e1ae4d..78392f1 100644 (file)
--- a/ChangeLog
+++ b/ChangeLog
@@ -78,7 +78,7 @@ Model checking:
  - Synchronize the MBI tests with upstream.
  - Show the full actor bactraces when replaying a MC trace (with model-check/replay)
    and the status of all actors on deadlocks in MC mode.
- - The safety/stateless aspects of the MC are now enabled by default in all simgrid builds.
+ - The safety/stateless aspects of the MC are now enabled by default in all SimGrid builds.
    Liveness and stateful aspects are still controled by the enabling_model-checking
    configuration option.
  - Stateless model-checking is now usable on any system, including Mac OSX and ARM processors.
@@ -242,7 +242,7 @@ MSG:
 New plugin: the Chaos Monkey (killing actors at any time)
  - Along with the new simgrid-monkey script, it tests whether your simulation
    resists resource failures at any possible timestamp in your simulation.
- - It is mostly intended to test the simgrid core in extreme conditions,
+ - It is mostly intended to test the SimGrid core in extreme conditions,
    but some users may find it interesting too.
 
 Models:
@@ -1006,7 +1006,7 @@ General:
  - Network model 'NS3' was renamed into 'ns-3'.
 
 Python:
- - Simgrid can now hopefully be installed with pip.
+ - SimGrid can now hopefully be installed with pip.
 
 S4U:
  - wait_any can now be used for asynchronous executions too.
@@ -2054,7 +2054,7 @@ SimGrid (3.12) stable; urgency=low
    - InfiniBand network model added: Based on the works of Jerome Vienne
      http://mescal.imag.fr/membres/jean-marc.vincent/index.html/PhD/Vienne.pdf
    - When smpi/display_timing is set, also display global simulation time and application times
-   - Have smpirun, smpicc and friends display the simgrid git hash version on --git-version
+   - Have smpirun, smpicc and friends display the SimGrid git hash version on --git-version
  * Collective communications
    - SMP-aware algorithms are now dynamically handled. An internal communicator is created for each node, and an external one to handle communications between "leaders" of each node
    - MVAPICH2 (1.9) collective algorithms selector: normal and SMP algorithms are handled, and selection logic is based on the one used on TACC's Stampede cluster (https://www.tacc.utexas.edu/stampede/).
@@ -2795,8 +2795,8 @@ SimGrid (3.6.2) stable; urgency=low
 
  Portability
  * Create an installer for windows with nsis (amd64 and win32)
-   - Add an hello world project to illustrate simgrid project creation.
-   - Embed libpcre into the Simgrid installer to avoid
+   - Add an hello world project to illustrate SimGrid project creation.
+   - Embed libpcre into the SimGrid installer to avoid
      its compilation burden
  * The raw execution contexts should work on Apple now
  * Port to Windows 64 bits
@@ -2829,7 +2829,7 @@ SimGrid (3.6.1) stable; urgency=low
 SimGrid-java (3.6) unstable; urgency=low
 
  * Initial release.
- * Split of every thing from simgrid v3.5 into a separate package.
+ * Split of every thing from SimGrid v3.5 into a separate package.
 
  -- 2011-10-05 Da SimGrid team <simgrid-devel@lists.gforge.inria.fr>
 
@@ -3343,7 +3343,7 @@ SimGrid (3.4) stable; urgency=low
   * Greatly improved our cdash/ctest interactions
     Check http://cdash.inria.fr/CDash/index.php?project=Simgrid
   * Added memory checking tests with valgrind; lot of memleak fixing.
-    This may be the first release of simgrid with so few memory issues
+    This may be the first release of SimGrid with so few memory issues
   * Added code coverage tests.
     Our coverage is still improvable, but at least we see it on cdash.
 
@@ -3649,7 +3649,7 @@ SimGrid (3.3.2) stable; urgency=low
 
  Timing report of this version:
   This version seem to be more than 5% faster than 3.3.1 (on linux
-    64bits with contextes). The gain is less than expected, we are
+    64bits with contexts). The gain is less than expected, we are
     investigating this for next release.
 
  -- Da SimGrid team <simgrid-devel@lists.gforge.inria.fr> Wed, 19 Aug 2009 17:07:12 +0200
@@ -3742,7 +3742,7 @@ SimGrid (3.3.1) stable; urgency=low
     - Linux(debian)/amd64/context
     - Linux(debian)/amd64/pthreads
     These targets fail about 1/10 of times on gras/pmm, but we believe
-      that this is because of the test, not because of simgrid.
+      that this is because of the test, not because of SimGrid.
     amok/saturate_sg fails even more rarely, and the test may not be
       the problem.
 
@@ -3799,7 +3799,7 @@ SimGrid (3.3) stable; urgency=high
     is really less memory-demanding, which should allow you to use
     larger files in SimGrid [AL].
 
-  * Inform valgrind about our contextes, so that it becomes usable
+  * Inform valgrind about our contexts, so that it becomes usable
     with the default (and more effecient) version of SimGrid
     [contributed by Sékou Diakite, many thanks]
 
index c8899ea..b4fb66f 100644 (file)
@@ -354,7 +354,7 @@ you should use to analyze your simulator.
 @li I want to trace the resource utilization of all hosts
 and links of the platform, and my simulator <b>does not</b> use
 the tracing API. For that, you can run a uncategorized trace
-with the following parameters (it will work with <b>any</b> Simgrid
+with the following parameters (it will work with <b>any</b> SimGrid
 simulator):
 @verbatim
 ./your_simulator @
index 37217f2..4bddc09 100644 (file)
@@ -3,7 +3,7 @@
 Simulating DAG
 ==============
 
-This tutorial presents the basics to understand how DAG are represented in Simgrid and how to simulate their workflow. 
+This tutorial presents the basics to understand how DAG are represented in SimGrid and how to simulate their workflow.
 
 Definition of a DAG
 -------------------
@@ -77,7 +77,7 @@ The goal of this lab is to describe the following DAG:
 In this DAG we want ``c1`` to compute 1e9 flops, ``c2`` to compute 5e9 flops and ``c3`` to compute 2e9 flops. 
 There is also a data transfer of 5e8 bytes between ``c1`` and ``c3``.
 
-First of all, include the Simgrid library and define the log category.
+First of all, include the SimGrid library and define the log category.
 
 .. literalinclude:: ../../examples/cpp/dag-tuto/s4u-dag-tuto.cpp
    :language: cpp
@@ -152,7 +152,7 @@ The execution of this code should give you the following output:
 Lab 2: Import a DAG from a file
 -------------------------------
 
-In this lab we present how to import a DAG into you Simgrid simulation, either using a DOT file, a JSON file, or a DAX file. 
+In this lab we present how to import a DAG into you SimGrid simulation, either using a DOT file, a JSON file, or a DAX file.
 
 The files presented in this lab describe the following DAG:
 
@@ -169,7 +169,7 @@ The following DOT file describes the workflow presented at the beginning of this
 .. literalinclude:: ../../examples/cpp/dag-from-dot-simple/dag.dot
    :language: dot
 
-It can be imported as a vector of Activities into Simgrid using :cpp:func:`simgrid::s4u::create_DAG_from_DOT`. Then, you have to assign hosts to your Activities.
+It can be imported as a vector of Activities into SimGrid using :cpp:func:`simgrid::s4u::create_DAG_from_DOT`. Then, you have to assign hosts to your Activities.
 
 .. literalinclude:: ../../examples/cpp/dag-from-dot-simple/s4u-dag-from-dot-simple.cpp
    :language: cpp
@@ -190,7 +190,7 @@ The following JSON file describes the workflow presented at the beginning of thi
 .. literalinclude:: ../../examples/cpp/dag-from-json-simple/dag.json
    :language: json
 
-It can be imported as a vector of Activities into Simgrid using :cpp:func:`simgrid::s4u::create_DAG_from_json`. 
+It can be imported as a vector of Activities into SimGrid using :cpp:func:`simgrid::s4u::create_DAG_from_json`.
 
 .. literalinclude:: ../../examples/cpp/dag-from-json-simple/s4u-dag-from-json-simple.cpp
    :language: cpp
@@ -211,7 +211,7 @@ The following DAX file describes the workflow presented at the beginning of this
 .. literalinclude:: ../../examples/cpp/dag-from-dax-simple/dag.xml
    :language: xml
 
-It can be imported as a vector of Activities into Simgrid using :cpp:func:`simgrid::s4u::create_DAG_from_DAX`.
+It can be imported as a vector of Activities into SimGrid using :cpp:func:`simgrid::s4u::create_DAG_from_DAX`.
 
 .. literalinclude:: ../../examples/cpp/dag-from-dax-simple/s4u-dag-from-dax-simple.cpp
    :language: cpp
@@ -279,7 +279,7 @@ Now that we have the key components of the algorithm let's merge them inside the
    {
    ...
 
-First, we initialize the Simgrid Engine.
+First, we initialize the SimGrid Engine.
 
 .. code-block:: cpp
 
index 34045cb..e5148af 100644 (file)
@@ -2846,7 +2846,7 @@ Error reporting
 
       The following errors denote a problem in the SimGrid tool itself. Most of the time, you should let these
       exception go, so that the simulation stops. But you may want to catch them, for example when you launch
-      simgrid from a python notebook and want to handle the problem accordingly.
+      SimGrid from a python notebook and want to handle the problem accordingly.
 
       .. doxygenclass:: simgrid::AssertionError
       .. doxygenclass:: simgrid::ParseError
@@ -2865,7 +2865,7 @@ Error reporting
 
       The following errors denote a problem in the SimGrid tool itself. Most of the time, you should let these
       exception go, so that the simulation stops. But you may want to catch them, for example when you launch
-      simgrid from a python notebook and want to handle the problem accordingly.
+      SimGrid from a python notebook and want to handle the problem accordingly.
 
       .. autoclass:: simgrid.AssertionError
 
index ab41d61..c5040da 100644 (file)
@@ -206,7 +206,7 @@ means that the selected algorithm will be used
    SimGrid. Some crashes can be expected while trying these algorithms
    with unusual sizes/parameters
 
-To retrive the full list of implemented algorithms in your version of SimGrid, simply use ``smpirun --help-coll``.
+To retrieve the full list of implemented algorithms in your version of SimGrid, simply use ``smpirun --help-coll``.
 
 MPI_Alltoall
 ^^^^^^^^^^^^
@@ -455,7 +455,7 @@ Adding an algorithm
 ^^^^^^^^^^^^^^^^^^^
 
 To add a new algorithm, one should check in the src/smpi/colls folder
-how other algorithms are coded. Using plain MPI code inside Simgrid
+how other algorithms are coded. Using plain MPI code inside SimGrid
 can't be done, so algorithms have to be changed to use smpi version of
 the calls instead (MPI_Send will become smpi_mpi_send). Some functions
 may have different signatures than their MPI counterpart, please check
@@ -473,7 +473,7 @@ Example: adding a "pair" version of the Alltoall collective.
 
  - To register the new version of the algorithm, simply add a line to the corresponding macro in src/smpi/colls/cools.h ( add a "COLL_APPLY(action, COLL_ALLTOALL_SIG, pair)" to the COLL_ALLTOALLS macro ). The algorithm should now be compiled and be selected when using --cfg=smpi/alltoall:pair at runtime.
 
- - To add a test for the algorithm inside Simgrid's test suite, juste add the new algorithm name in the ALLTOALL_COLL list found inside teshsuite/smpi/CMakeLists.txt . When running ctest, a test for the new algorithm should be generated and executed. If it does not pass, please check your code or contact us.
+ - To add a test for the algorithm inside SimGrid's test suite, juste add the new algorithm name in the ALLTOALL_COLL list found inside teshsuite/smpi/CMakeLists.txt . When running ctest, a test for the new algorithm should be generated and executed. If it does not pass, please check your code or contact us.
 
  - Please submit your patch for inclusion in SMPI, for example through a pull request on GitHub or directly per email.
 
@@ -581,11 +581,11 @@ the exact same file several times, be it a library or a relocatable
 executable. It makes perfectly sense in the general case, but we need
 to circumvent this rule of thumb in our case. To that extend, the
 binary is copied in a temporary file before being re-linked against.
-``dlmopen()`` cannot be used as it only allows 256 contextes, and as it
-would also duplicate simgrid itself.
+``dlmopen()`` cannot be used as it only allows 256 contexts, and as it
+would also duplicate SimGrid itself.
 
 This approach greatly speeds up the context switching, down to about
-40 CPU cycles with our raw contextes, instead of requesting several
+40 CPU cycles with our raw contexts, instead of requesting several
 syscalls with the ``mmap()`` approach. Another advantage is that it
 permits one to run the SMPI contexts in parallel, which is obviously not
 possible with the ``mmap()`` approach. It was tricky to implement, but
@@ -604,7 +604,7 @@ implementation leads.\n
 Also, currently, only the binary is copied and dlopen-ed for each MPI
 rank. We could probably extend this to external dependencies, but for
 now, any external dependencies must be statically linked into your
-application. As usual, simgrid itself shall never be statically linked
+application. As usual, SimGrid itself shall never be statically linked
 in your app. You don't want to give a copy of SimGrid to each MPI rank:
 that's ways too much for them to deal with.
 
index dbf2671..582d016 100644 (file)
@@ -20,7 +20,7 @@ RUN printf '%s\n' \
     r-cran-plyr \
     r-cran-jsonlite \
     r-cran-gridextra \
-# simgrid dependencies
+# SimGrid dependencies
     g++ \
     gcc \
     git \
@@ -41,7 +41,7 @@ RUN printf '%s\n' \
 RUN mkdir /source && cd /source && \
     git clone https://github.com/msnoigrs/ox-rst.git ox-rst.git
 
-# compile install simgrid
+# compile install SimGrid
 RUN cd /source && git clone --depth=1 https://framagit.org/simgrid/simgrid.git simgrid.git && \
     cd simgrid.git && \
     cmake -DCMAKE_INSTALL_PREFIX=/usr/ -Denable_documentation=OFF -Denable_smpi=ON -Denable_compile_optimizations=ON . && \
index 3bf0cb6..105aa7d 100644 (file)
@@ -15,7 +15,7 @@ RUN printf '%s\n' \
     r-cran-dplyr \
     r-cran-irkernel \
     r-cran-quantreg \
-# simgrid dependencies
+# SimGrid dependencies
     g++ \
     gcc \
     git \
@@ -63,7 +63,7 @@ RUN pip install --no-cache-dir --upgrade pip && \
     papermill==2.3.3 \
     ipywidgets==7.6.5
 
-# simgrid
+# SimGrid
 RUN mkdir -p /source && cd /source && git clone --depth=1 https://framagit.org/simgrid/simgrid.git simgrid.git && \
     cd simgrid.git && \
     cmake -DCMAKE_INSTALL_PREFIX=/usr/ -Denable_documentation=OFF -Denable_smpi=ON -Denable_compile_optimizations=ON . && \
index 162233c..2ac5db2 100644 (file)
@@ -39,7 +39,7 @@ public:
  *
  * @param latency_base The base latency for this calibration (user-defined)
  * @param seg Segmentation (user-defined)
- * @param size Message size (simgrid)
+ * @param size Message size (SimGrid)
  */
 static double latency_factor_cb(double latency_base, const SegmentedRegression& seg, double size,
                                 const sg4::Host* /*src*/, const sg4::Host* /*dst*/,
@@ -57,7 +57,7 @@ static double latency_factor_cb(double latency_base, const SegmentedRegression&
  *
  * @param bw_base The base bandwidth for this calibration (user-defined)
  * @param seg Segmentation (user-defined)
- * @param size Message size (simgrid)
+ * @param size Message size (SimGrid)
  */
 static double bw_factor_cb(double bw_base, const SegmentedRegression& seg, double size, const sg4::Host* /*src*/,
                            const sg4::Host* /*dst*/, const std::vector<sg4::Link*>& /*links*/,
index cc817e3..d48288b 100644 (file)
@@ -38,7 +38,7 @@ public:
  *
  * @param latency_base The base latency for this calibration (user-defined)
  * @param seg Segmentation (user-defined)
- * @param size Message size (simgrid)
+ * @param size Message size (SimGrid)
  */
 static double latency_factor_cb(double latency_base, const SegmentedRegression& seg, double size,
                                 const sg4::Host* /*src*/, const sg4::Host* /*dst*/,
@@ -56,7 +56,7 @@ static double latency_factor_cb(double latency_base, const SegmentedRegression&
  *
  * @param bw_base The base bandwidth for this calibration (user-defined)
  * @param seg Segmentation (user-defined)
- * @param size Message size (simgrid)
+ * @param size Message size (SimGrid)
  */
 static double bw_factor_cb(double bw_base, const SegmentedRegression& seg, double size, const sg4::Host* /*src*/,
                            const sg4::Host* /*dst*/, const std::vector<sg4::Link*>& /*links*/,
index 8f7ebf2..7b77c0e 100644 (file)
     "import json\n",
     "\n",
     "def plot_compare(df):\n",
-    "    \"\"\" Auxiliary function to compare simgrid and reality \"\"\"\n",
+    "    \"\"\" Auxiliary function to compare SimGrid and reality \"\"\"\n",
     "    func = list(df['op'].unique())\n",
     "    assert len(func) == 1\n",
     "    func = func[0]\n",
     }
    ],
    "source": [
-    "# simgrid has fewer executions than real life, keep the same amount of samples for better visualization\n",
+    "# SimGrid has fewer executions than real life, keep the same amount of samples for better visualization\n",
     "N = df_smpi_send.groupby(\"msg_size\").size().iloc[0]\n",
     "\n",
     "tmp = pandas.concat([df_send.groupby(\"msg_size\").sample(N), df_smpi_send, df_isend.groupby(\"msg_size\").sample(N), df_smpi_isend, df_recv.groupby(\"msg_size\").sample(N), df_smpi_recv, df_pingpong.groupby(\"msg_size\").sample(N), df_smpi_pingpong])\n",
     }
    ],
    "source": [
-    "# simgrid has fewer executions than real life, keep the same amount of samples for better visualization\n",
+    "# SimGrid has fewer executions than real life, keep the same amount of samples for better visualization\n",
     "N = df_smpi_send.groupby(\"msg_size\").size().iloc[0]\n",
     "\n",
     "tmp = pandas.concat([df_send.groupby(\"msg_size\").sample(N), df_smpi_send, df_isend.groupby(\"msg_size\").sample(N), df_smpi_isend, df_recv.groupby(\"msg_size\").sample(N), df_smpi_recv, df_pingpong.groupby(\"msg_size\").sample(N), df_smpi_pingpong])\n",
index 99a2054..7a3d02d 100644 (file)
@@ -10,7 +10,7 @@ Specially, it is based on Tom Cornebize’s Phd thesis (https://tel.archives-ouv
 
 You can execute the notebook `network_calibration_tutorial.ipynb <https://framagit.org/simgrid/simgrid/tree/master/docs/source/tuto_network_calibration/network_calibration_tutorial.ipynb>`_) by yourself using the docker image
 available at: `Dockerfile <https://framagit.org/simgrid/simgrid/tree/master/docs/source/tuto_network_calibration/Dockerfile>`_. For that, run the
-following commands in the tutorial folder inside simgrid's code source (``docs/source/tuto_network_calibration``):
+following commands in the tutorial folder inside SimGrid's code source (``docs/source/tuto_network_calibration``):
 
 .. code-block::
 
index ecc2cc4..e412cd4 100644 (file)
@@ -6,7 +6,7 @@ library(pajengr)
 # Load and relabel the data
 df = pajeng_read(args[1])
 df$state %>%
-    # rename some columns to use simgrid terminology
+    # rename some columns to use SimGrid terminology
     rename(Actor = Container,
            State = Value) %>%
     # do the plot
index cbe1f7e..5e0220f 100644 (file)
@@ -1,4 +1,4 @@
-.. S4U (Simgrid for you) is the modern interface of SimGrid, which new project should use.
+.. S4U (SimGrid for you) is the modern interface of SimGrid, which new project should use.
 ..
 .. This file follows the ReStructured syntax to be included in the
 .. documentation, but it should remain readable directly.
index f55da7f..8b92c0b 100644 (file)
@@ -77,7 +77,7 @@ int main(int argc, char* argv[])
   /* Become one of the simulated actors (must be done after the platform creation, or the host won't exist). */
   sg_actor_attach("sender", nullptr, e.host_by_name("Tremblay"), nullptr);
 
-  ensure_root_tid(); // Only useful in this test: we ensure that simgrid is not broken and that this code is executed in
+  ensure_root_tid(); // Only useful in this test: we ensure that SimGrid is not broken and that this code is executed in
                      // the correct system thread
 
   // Execute the sender code. The root thread was actually turned into a regular actor
index 383eef3..9688bed 100644 (file)
@@ -15,9 +15,9 @@ namespace sg4 = simgrid::s4u;
  * in collective operations. But it doesn't happen in this example
  *
  * @param op MPI Operation (set by user at cb registering below)
- * @param size Message size (set by simgrid)
- * @param src Source host (set by simgrid)
- * @param dst Source host (set by simgrid)
+ * @param size Message size (set by SimGrid)
+ * @param src Source host (set by SimGrid)
+ * @param dst Source host (set by SimGrid)
  */
 static double smpi_cost_cb(SmpiOperation op, size_t /*size*/, const sg4::Host* src, const sg4::Host* dst)
 {
index 97f399d..f865162 100644 (file)
@@ -42,8 +42,10 @@ int main(int argc, char *argv[])
     MPI_Send(&msg, 1, MPI_INT, dst, tag1, MPI_COMM_WORLD);
 
     /* Inject five seconds of fake computation time */
-    /* We are in a public file, not internal to simgrid, so _benched flavour is preferred, as it protects against accidental skip */
-    /* smpi_execute_benched here is mostly equivalent to sleep, which is intercepted by smpi and turned into smpi_sleep */
+    /* We are in a public file, not internal to SimGrid, so _benched flavour is preferred, as it protects against
+     * accidental skip */
+    /* smpi_execute_benched here is mostly equivalent to sleep, which is intercepted by smpi and turned into smpi_sleep
+     */
     /* Difference with sleep is only for energy consumption */
     smpi_execute_benched(5.0);
 
@@ -56,7 +58,8 @@ int main(int argc, char *argv[])
     msg++;
 
     /* Inject 762.96 Mflops of computation time - Host Jupiter is 76.296Mf per second, so this should amount to 10s */
-    /* We are in a public file, not internal to simgrid, so _benched flavour is preferred, as it protects against accidental skip */
+    /* We are in a public file, not internal to SimGrid, so _benched flavour is preferred, as it protects against
+     * accidental skip */
     smpi_execute_flops_benched(762960000);
 
     printf("[%d] After a nap, increment message's value to  '%d'\n", rank, msg);
index d3ff02b..b5b6524 100644 (file)
@@ -51,9 +51,9 @@ XBT_PUBLIC void simgrid_set_maestro(void (*code)(void*), void* data);
 
 /** @brief Allow other libraries to react to the --help flag, too
  *
- * When finding --help on the command line, simgrid usually stops right after displaying its help message.
- * If you are writing a library using simgrid, you may want to display your own help message before everything stops.
- * If so, just call this function before having simgrid parsing the command line, and you will be given the control
+ * When finding --help on the command line, SimGrid usually stops right after displaying its help message.
+ * If you are writing a library using SimGrid, you may want to display your own help message before everything stops.
+ * If so, just call this function before having SimGrid parsing the command line, and you will be given the control
  * even if the user is asking for help.
  */
 XBT_PUBLIC void sg_config_continue_after_help();
index d21a7fa..f39ff67 100644 (file)
@@ -305,12 +305,12 @@ typedef s4u_Actor* sg_actor_t;
 typedef const s4u_Actor* const_sg_actor_t;
 
 /** @ingroup m_datatypes_management_details
- * @brief Type for any simgrid size
+ * @brief Type for any SimGrid size
  */
 typedef unsigned long long sg_size_t;
 
 /** @ingroup m_datatypes_management_details
- * @brief Type for any simgrid offset
+ * @brief Type for any SimGrid offset
  */
 typedef long long sg_offset_t;
 
index db406d3..f639047 100644 (file)
@@ -13,7 +13,7 @@
 #include <xbt/base.h>
 
 namespace simgrid {
-/** Returns the ns3 node from a simgrid host */
+/** Returns the ns3 node from a SimGrid host */
 XBT_PUBLIC ns3::Ptr<ns3::Node> get_ns3node_from_sghost(const simgrid::s4u::Host* host);
 }; // namespace simgrid
 
index beff27c..46f7ae2 100644 (file)
@@ -209,7 +209,7 @@ public:
   /** @brief set a configuration variable
    *
    * @beginrst
-   * Do --help on any simgrid binary to see the list of currently existing configuration variables
+   * Do --help on any SimGrid binary to see the list of currently existing configuration variables
    * (see also :ref:`options`).
    * @endrst
    *
index d39a948..d12022c 100644 (file)
@@ -1,4 +1,4 @@
-/* xbt.h - Public interface to the xbt (simgrid's toolbox)                  */
+/* xbt.h - Public interface to the xbt (SimGrid's toolbox)                  */
 
 /* Copyright (c) 2004-2023. The SimGrid Team. All rights reserved.          */
 
index da34afa..0c45e62 100644 (file)
@@ -1,4 +1,4 @@
-/* xbt.h - Public interface to the xbt (simgrid's toolbox)                  */
+/* xbt.h - Public interface to the xbt (SimGrid's toolbox)                  */
 
 /* Copyright (c) 2004-2023. The SimGrid Team. All rights reserved.          */
 
index e78e0bd..160fb7e 100644 (file)
@@ -22,7 +22,7 @@
 SG_BEGIN_DECL
 
 #ifdef XBT_LOG_LOCALLY_DEFINE_XBT_CHANNEL
-XBT_LOG_NEW_CATEGORY(xbt, "All XBT categories (simgrid toolbox)");
+XBT_LOG_NEW_CATEGORY(xbt, "All XBT categories (SimGrid toolbox)");
 XBT_LOG_NEW_SUBCATEGORY(xbt_help, xbt, "Help messages");
 #else
 XBT_LOG_EXTERNAL_CATEGORY(xbt);
index d5ad57b..2c1807d 100755 (executable)
--- a/setup.py
+++ b/setup.py
@@ -38,7 +38,7 @@ class CMakeBuild(build_ext):
 
         if not os.path.exists("MANIFEST.in"):
             raise RuntimeError(
-                "Please generate a MANIFEST.in file (configure simgrid, and copy it here if you build out of tree)")
+                "Please generate a MANIFEST.in file (configure SimGrid, and copy it here if you build out of tree)")
 
         for ext in self.extensions:
             self.build_extension(ext)
index 0ba9186..b206442 100644 (file)
@@ -404,7 +404,7 @@ double NetworkNS3Model::next_occurring_event(double sg_time)
   }
 
   double ns3_time = ns3::Simulator::GetNextEventTime().GetSeconds();
-  XBT_DEBUG("NS3 tells that the next occuring event is at %f (it's %f in simgrid), so NS3 returns a delta of %f.",
+  XBT_DEBUG("NS3 tells that the next occuring event is at %f (it's %f in SimGrid), so NS3 returns a delta of %f.",
             ns3_time, sg_time, ns3_time - sg_time);
   return ns3_time - sg_time;
 }
index 5e6318b..32e395f 100644 (file)
@@ -30,7 +30,7 @@ namespace simgrid::mc {
  * in which vector clocks are typically used).
  *
  * Support, however, needs to be added to clock vectors since
* Simgrid permits the *creation* of new actors during execution.
  * Since we don't know this size before-hand, we have to allow
  * clock vectors to behave as if they were "infinitely" large. To
  * do so, all newly mapped elements, if not assigned a value, are
index cfa440d..0852cd2 100644 (file)
@@ -103,7 +103,7 @@ public:
 
   /**
    * @brief Computes the backtrack set for this state
* according to its definition in Simgrid.
    *
    * The backtrack set as it appears in DPOR, SDPOR, and ODPOR
    * in SimGrid consists of those actors marked as `todo`
index a2f7310..32f78ef 100644 (file)
@@ -9,7 +9,7 @@
  *  The recorded path is written in the log output and can be replayed with MC disabled
  *  (even with a non-MC build) using `--cfg=model-check/replay:$replayPath`.
  *
*  The same version of Simgrid should be used and the same arguments should be
  *  passed to the application (without the MC specific arguments).
  */
 
index 11b8b48..2aa9dbc 100644 (file)
@@ -22,7 +22,7 @@
 #include <algorithm>
 #include <string>
 
-XBT_LOG_NEW_CATEGORY(s4u, "Log channels of the S4U (Simgrid for you) interface");
+XBT_LOG_NEW_CATEGORY(s4u, "Log channels of the S4U (SimGrid for you) interface");
 XBT_LOG_NEW_DEFAULT_SUBCATEGORY(s4u_engine, s4u, "Logging specific to S4U (engine)");
 
 static simgrid::kernel::actor::ActorCode maestro_code;
index fb1df9d..98e0648 100644 (file)
@@ -31,9 +31,9 @@ static simgrid::config::Flag<bool> cfg_continue_after_help
 
 /** @brief Allow other libraries to react to the --help flag, too
  *
* When finding --help on the command line, simgrid usually stops right after displaying its help message.
* If you are writing a library using simgrid, you may want to display your own help message before everything stops.
* If so, just call this function before having simgrid parsing the command line, and you will be given the control
  * even if the user is asking for help.
  */
 void sg_config_continue_after_help()
index 684bcb6..d3419b2 100644 (file)
@@ -1,4 +1,4 @@
/* selector with default/naive Simgrid algorithms. These should not be trusted for performance evaluations */
 
 /* Copyright (c) 2009-2023. The SimGrid Team. All rights reserved.          */
 
index 03e03e8..10fbc85 100644 (file)
@@ -25,7 +25,7 @@
       for (const auto& elem : (action)) {                                                                              \
         ss << elem << " ";                                                                                             \
       }                                                                                                                \
-      ss << "\nPlease contact the Simgrid team if support is needed";                                                  \
+      ss << "\nPlease contact the SimGrid team if support is needed";                                                  \
       throw std::invalid_argument(ss.str());                                                                           \
     }                                                                                                                  \
   }
index a8b26a6..f661498 100644 (file)
@@ -51,7 +51,7 @@ class Request : public F2C {
   MPI_Op op_;
   std::unique_ptr<smpi_mpi_generalized_request_funcs_t> generalized_funcs;
   std::vector<MPI_Request> nbc_requests_;
-  s4u::Host* src_host_ = nullptr; //!< save simgrid's source host since it can finished before the recv
+  s4u::Host* src_host_ = nullptr; //!< save SimGrid's source host since it can finished before the recv
   static bool match_common(MPI_Request req, MPI_Request sender, MPI_Request receiver);
   static bool match_types(MPI_Datatype stype, MPI_Datatype rtype);
 
index 4d04e09..ee9e084 100644 (file)
@@ -19,7 +19,7 @@
 #include <valgrind/valgrind.h>
 #endif
 
/* We don't want to intercept pthread within simgrid. Instead we should provide the real implem to simgrid */
 static int (*raw_pthread_create)(pthread_t*, const pthread_attr_t*, void* (*)(void*), void*);
 static int (*raw_pthread_join)(pthread_t, void**);
 static int (*raw_mutex_init)(pthread_mutex_t*, const pthread_mutexattr_t*);
index d5a0a55..944e2a1 100644 (file)
@@ -67,7 +67,7 @@ static inline void lock_release(xbt_mallocator_t m)
  * This function must be called once the framework configuration is done. mallocators will not get used until it's
  * called (check the implementation notes above for more info).
  *
* sg_config uses this function to inform the mallocators when simgrid is configured, and whether lock protection is
  * needed.
  */
 void xbt_mallocator_initialization_is_done(int need_protection)
index 2775b84..72bbbec 100644 (file)
@@ -9,7 +9,7 @@
  * It is not written to be pleasant to read, but instead to resist the aggressions of the monkey:
  * - Workers keep going until after a global variable `todo` reaches 0.
  * - The master is a daemon that just sends infinitely tasks
*   (simgrid simulations stop as soon as all non-daemon actors are done).
  * - The platform is created programmatically to remove path issues and control the problem size.
  *
  * Command-line configuration items:
index 6db4f0c..26944b7 100644 (file)
@@ -10,7 +10,7 @@
  It is not written to be pleasant to read, but instead to resist the aggressions of the monkey:
  - Workers keep going until after a global variable `todo` reaches 0.
  - The master is a daemon that just sends infinitely tasks
-   (simgrid simulations stop as soon as all non-daemon actors are done).
+   (SimGrid simulations stop as soon as all non-daemon actors are done).
  - The platform is created programmatically to remove path issues and control the problem size.
 
  See the simgrid-monkey script for more information.
index 35613f1..d4f9eb8 100644 (file)
@@ -38,7 +38,7 @@ if (enable_smpi_MBI_testsuite)
   add_dependencies(tests tests-mbi)
   add_dependencies(tests-mbi simgrid-mc smpimain)
 
# Remove Concurrency tests that are out of reach because simgrid does not intercept local modifications yet
   # An idea could be to use ASan on the verified application, along with https://github.com/google/sanitizers/wiki/AddressSanitizerManualPoisoning
   # But currently, ASan is not usable at all, since the Checker dislikes this trick when it tries to read the memory of the app.
   # We should change the checker to not read the app when verifying safty properties
index d47dba9..0992475 100644 (file)
@@ -1,7 +1,7 @@
 # Smpi Allreduce collectives tests
 ! output sort
 
-p Test allreduce with papi events activated - needs papi installed, simgrid compiled with it, and sudo or sudo sh -c "echo 0 > /proc/sys/kernel/perf_event_paranoid"
+p Test allreduce with papi events activated - needs papi installed, SimGrid compiled with it, and sudo or sudo sh -c "echo 0 > /proc/sys/kernel/perf_event_paranoid"
 $ ${bindir:=.}/../../../smpi_script/bin/smpirun -map -hostfile ../hostfile_coll -platform ${platfdir:=.}/small_platform.xml -np 16 -trace --log=xbt_cfg.thres:critical ${bindir:=.}/coll-allreduce --log=smpi_config.thres:warning --log=smpi_coll.thres:error --log=smpi_mpi.thres:error --log=smpi_pmpi.thres:error --cfg=smpi/papi-events:default:PAPI_L1_TCM:PAPI_TOT_CYC
 > [0.000000] [smpi/INFO] [rank 0] -> Tremblay
 > [0.000000] [smpi/INFO] [rank 1] -> Tremblay
index 28c0892..5fa39d6 100644 (file)
@@ -777,7 +777,7 @@ else() # NOT ucontext
                                 src/kernel/context/ContextUnix.cpp)
 endif()
 
### Simgrid Lib sources
 set(simgrid_sources
   ${S4U_SRC}
   ${SIMGRID_SRC}
index ece7a08..f435e01 100755 (executable)
@@ -22,7 +22,7 @@ for i in master 1.3 ; do
 
   # NOTE: Do *not* introduce parameters to "make it work" here.
   # Things should "just work" with default parameters!
# Users should not have to tinker to get starpu working on top of simgrid, that is precisely why we have this CI
 
   if [ $i = master ]; then
     # On master, fail if we use deprecated functions, so that StarPU people know they have to stop using them, fix it, and thus make CI happy again
index 5d3eb0d..e8ec004 100644 (file)
@@ -6,7 +6,7 @@ def getcwd():
 prefix=getcwd()+"/install"
 #Add the condition testing to run tests and includes PyYaml
 conditions.add("testing")
-conditions.add("simulation") #to include simgrid compilation
+conditions.add("simulation") #to include SimGrid compilation
 #List the module the this rcfile will build
 modules = ['spred',]
 #example of the potentialities of the python syntax in this file
index 8a70894..c5699ea 100755 (executable)
@@ -1,6 +1,6 @@
 #! /usr/bin/env python3
 
# The goal is to introduce random failures in a simulation, to test simgrid under extreme conditions.
 # 
 # It is made of several components.
 # 
@@ -13,7 +13,7 @@
 #     Kill the link #0 after 42 seconds (using a kernel::Timer)
 # 
 # * a python script: tools/simgrid-monkey (this file)
#   * It takes a regular simgrid simulation as a parameter, use the cmonkey plugin to get the information about it, 
 #     and then restart many runs, with one resource being turn_off() + turn_on() in each run.
 #   * Each resource gets killed between each timestamps, and on each timestamp.
 #   * So the amount of simulations is: 1 + (host_c+link_c) * timestamps * 2
@@ -65,7 +65,7 @@ def get_info(cmd):
     #print(f"hosts:{host_count} links:{link_count} timestamps:{' '.join(([str(i) for i in timestamps]))}")
     return (host_count,  link_count,  timestamps)
 
-parser = argparse.ArgumentParser(description='Run a simgrid simulation, and turn off/on resources at random.')
+parser = argparse.ArgumentParser(description='Run a SimGrid simulation, and turn off/on resources at random.')
 parser.add_argument('--valgrind', help="Run the simulations in valgrind")
 parser.add_argument('command', nargs='*')
 args = parser.parse_args()
index b31bdbc..8c9cd3e 100755 (executable)
@@ -7,7 +7,7 @@
 
 '''
 This script is intended to convert SMPI time independent traces (TIT) from the
-old format (simgrid version <= 3.19) to the new format.
+old format (SimGrid version <= 3.19) to the new format.
 
 On the previous format each MPI_wait calls were associated to the last ISend of
 IRecv call arbitrarily.
@@ -15,7 +15,7 @@ IRecv call arbitrarily.
 This new that includes tags field that links MPI_wait calls to the
 MPI_ISend or MPI_IRecv associated to this wait.
 
-This script reproduce the old behavior of simgrid because information are
+This script reproduce the old behavior of SimGrid because information are
 missing to add the tags properly. It also lower case all the mpi calls.
 
 It takes in input (as argument or in stdin) the trace list file that is only a
index defb1ec..e62d011 100755 (executable)
@@ -2,7 +2,7 @@
 eval 'exec perl -S $0 ${1+"$@"}'
     if $running_under_some_shell;
 
# This script updates the simgrid XML file passed as argument (modification in place)
 # It is built to do the conversion incrementally.
 
 # Copyright (c) 2006-2023. The SimGrid Team.
@@ -15,7 +15,7 @@ eval 'exec perl -S $0 ${1+"$@"}'
 
 =head1 NAME
 
-simgrid_update_xml - updates simgrid XML files to latest version
+simgrid_update_xml - updates SimGrid XML files to latest version
 
 =head1 SYNOPSIS
 
@@ -23,7 +23,7 @@ B<simgrid_update_xml> I<xml_file>
 
 =head1 DESCRIPTION
 
-simgrid_update_xml updates the simgrid XML file passed as argument.  The file
+simgrid_update_xml updates the SimGrid XML file passed as argument.  The file
 is modified in place, without any kind of backup. You may want to save a copy
 before running the script.
@@ -30,7 +30,7 @@ namespace simgrid::mc {
  *
  * Support, however, needs to be added to clock vectors since
- * Simgrid permits the *creation* of new actors during execution.
+ * SimGrid permits the *creation* of new actors during execution.
  * Since we don't know this size before-hand, we have to allow
  * clock vectors to behave as if they were "infinitely" large. To
@@ -103,7 +103,7 @@ public:
   /**
    * @brief Computes the backtrack set for this state
-   * according to its definition in Simgrid.
+   * according to its definition in SimGrid.
    *
    * The backtrack set as it appears in DPOR, SDPOR, and ODPOR
@@ -9,7 +9,7 @@
  *  (even with a non-MC build) using `--cfg=model-check/replay:$replayPath`.
  *
- *  The same version of Simgrid should be used and the same arguments should be
+ *  The same version of SimGrid should be used and the same arguments should be
  *  passed to the application (without the MC specific arguments).
  */
@@ -31,9 +31,9 @@ static simgrid::config::Flag<bool> cfg_continue_after_help
 /** @brief Allow other libraries to react to the --help flag, too
  *
- * When finding --help on the command line, simgrid usually stops right after displaying its help message.
- * If you are writing a library using simgrid, you may want to display your own help message before everything stops.
- * If so, just call this function before having simgrid parsing the command line, and you will be given the control
+ * When finding --help on the command line, SimGrid usually stops right after displaying its help message.
+ * If you are writing a library using SimGrid, you may want to display your own help message before everything stops.
+ * If so, just call this function before having SimGrid parsing the command line, and you will be given the control
  * even if the user is asking for help.
  */
@@ -1,4 +1,4 @@
index 684bcb6..d3419b2 100644 (file)
-/* selector with default/naive Simgrid algorithms. These should not be trusted for performance evaluations */
+/* selector with default/naive SimGrid algorithms. These should not be trusted for performance evaluations */
 
 /* Copyright (c) 2009-2023. The SimGrid Team. All rights reserved.          */
@@ -19,7 +19,7 @@
 #endif
 
-/* We don't want to intercept pthread within simgrid. Instead we should provide the real implem to simgrid */
+/* We don't want to intercept pthread within SimGrid. Instead we should provide the real implem to SimGrid */
 static int (*raw_pthread_create)(pthread_t*, const pthread_attr_t*, void* (*)(void*), void*);
 static int (*raw_pthread_join)(pthread_t, void**);
@@ -67,7 +67,7 @@ static inline void lock_release(xbt_mallocator_t m)
  * called (check the implementation notes above for more info).
  *
- * sg_config uses this function to inform the mallocators when simgrid is configured, and whether lock protection is
+ * sg_config uses this function to inform the mallocators when SimGrid is configured, and whether lock protection is
  * needed.
  */
@@ -9,7 +9,7 @@
  * - Workers keep going until after a global variable `todo` reaches 0.
  * - The master is a daemon that just sends infinitely tasks
- *   (simgrid simulations stop as soon as all non-daemon actors are done).
+ *   (SimGrid simulations stop as soon as all non-daemon actors are done).
  * - The platform is created programmatically to remove path issues and control the problem size.
  *
@@ -38,7 +38,7 @@ if (enable_smpi_MBI_testsuite)
   add_dependencies(tests-mbi simgrid-mc smpimain)
 
-  # Remove Concurrency tests that are out of reach because simgrid does not intercept local modifications yet
+  # Remove Concurrency tests that are out of reach because SimGrid does not intercept local modifications yet
   # An idea could be to use ASan on the verified application, along with https://github.com/google/sanitizers/wiki/AddressSanitizerManualPoisoning
   # But currently, ASan is not usable at all, since the Checker dislikes this trick when it tries to read the memory of the app.
@@ -777,7 +777,7 @@ else() # NOT ucontext
 endif()
 
-### Simgrid Lib sources
+### SimGrid Lib sources
 set(simgrid_sources
   ${S4U_SRC}
@@ -22,7 +22,7 @@ for i in master 1.3 ; do
   # NOTE: Do *not* introduce parameters to "make it work" here.
   # Things should "just work" with default parameters!
-  # Users should not have to tinker to get starpu working on top of simgrid, that is precisely why we have this CI
+  # Users should not have to tinker to get starpu working on top of SimGrid, that is precisely why we have this CI
 
   if [ $i = master ]; then
@@ -1,6 +1,6 @@
 #! /usr/bin/env python3
 
-# The goal is to introduce random failures in a simulation, to test simgrid under extreme conditions.
+# The goal is to introduce random failures in a simulation, to test SimGrid under extreme conditions.
 # 
 # It is made of several components.
@@ -13,7 +13,7 @@
 # 
 # * a python script: tools/simgrid-monkey (this file)
-#   * It takes a regular simgrid simulation as a parameter, use the cmonkey plugin to get the information about it, 
+#   * It takes a regular SimGrid simulation as a parameter, use the cmonkey plugin to get the information about it, 
 #     and then restart many runs, with one resource being turn_off() + turn_on() in each run.
 #   * Each resource gets killed between each timestamps, and on each timestamp.
@@ -2,7 +2,7 @@
     if $running_under_some_shell;
 
-# This script updates the simgrid XML file passed as argument (modification in place)
+# This script updates the SimGrid XML file passed as argument (modification in place)
 # It is built to do the conversion incrementally.
 